@@ -4,7 +4,7 @@ import argparse
 import errno
 import getpass
 import glob
-import importlib.machinery
+import importlib
 import os
 import pwd
 import stat
@@ -61,10 +61,19 @@ def blue(line:str) -> None:
         print(line)
 
 
+def get_parser():
+    # https://stackoverflow.com/a/43602645
+    path = importlib.machinery.SourceFileLoader('name',
+             os.path.join(GENERATOR_DIR, 'systemd-crontab-generator'))
+    spec = importlib.util.spec_from_loader('name', path)
+    module = importlib.util.module_from_spec(spec)
+    loader = spec.loader
+    loader.exec_module(module)
+    return module
+
+
 def translate(line:str, args) -> None:
-    loader = importlib.machinery.SourceFileLoader('name',
-                os.path.join(GENERATOR_DIR, 'systemd-crontab-generator'))
-    parser = loader.load_module()
+    parser = get_parser()
     line = args.file
     print(line)
 
@@ -85,21 +94,19 @@ def translate(line:str, args) -> None:
 
 def check(cron_file:str) -> bool:
     good = True
-    loader = importlib.machinery.SourceFileLoader('name',
-                os.path.join(GENERATOR_DIR, 'systemd-crontab-generator'))
-    parser = loader.load_module()
+    parser = get_parser()
     for job in parser.parse_crontab(cron_file, withuser=False):
         if not job.valid:
             good = False
             sys.stderr.write('%s: truncated line in %s: %s\n' % (SELF, cron_file, job.line))
-        elif type(job.period) is str:
+        elif job.period:
             if job.period not in ['reboot', 'minutely', 'hourly', 'daily', 'midnight', 'weekly',
                                 'monthly', 'quarterly',
                                 'semi-annually', 'semiannually', 'bi-annually', 'biannually',
                                 'annually', 'yearly']:
                 good = False
                 sys.stderr.write("%s: unknown schedule in %s: %s\n" % (SELF, cron_file, job.line))
-        elif '0' in job.timespec_month or '0' in job.timespec_day:
+        elif '0' in job.timespec_month or '0' in job.timespec_dom:
                 good = False
                 sys.stderr.write("%s: month and day can't be 0 in %s: %s\n" % (SELF, cron_file, job.line))
     return good
