@@ -46,6 +46,8 @@ CROND2TIMER = {
     'sysstat': 'sysstat-collect',
 }
 
+TARGET_DIR = '/tmp'
+
 for pgm in ('/usr/sbin/sendmail', '/usr/lib/sendmail'):
     if os.path.exists(pgm):
         HAS_SENDMAIL = True
@@ -267,16 +269,17 @@ class Job:
 
     def decode_command(self) -> None:
         '''perform smart substitutions for known shells'''
-        if self.shell not in KSH_SHELLS:
-            return
+        if not self.home:
+            # home can be set by tests to avoid
+            # to read the real /etc/passwd
+            try:
+                self.home = pwd.getpwnam(self.user).pw_dir
+            except KeyError:
+                pass
 
-        try:
-            self.home = pwd.getpwnam(self.user).pw_dir
-        except KeyError:
-            pass
         if self.home:
             if self.command[0].startswith('~/'):
-                self.command[0] = self.home + self.command[0][2:]
+                self.command[0] = self.home + self.command[0][1:]
 
             if 'PATH' in self.environment:
                 parts = self.environment['PATH'].split(':')
@@ -285,6 +288,12 @@ class Job:
                         parts[i] = self.home + part[1:]
                 self.environment['PATH'] = ':'.join(parts)
 
+        if self.shell not in KSH_SHELLS:
+            return
+
+        pgm = which(self.command[0])
+        if pgm and pgm != self.command[0]:
+            self.command[0] = pgm
 
         if (len(self.command) >= 3 and
             self.command[-2] == '>' and
@@ -447,11 +456,6 @@ class Job:
             if os.path.isfile(self.command[0]):
                 self.execstart = self.command[0]
                 return None
-            else:
-                pgm = which(self.command[0])
-                if pgm:
-                    self.execstart = pgm
-                    return None
 
         self.scriptlet = os.path.join(TARGET_DIR, '%s.sh' % self.unit_name)
         self.execstart = self.shell + ' ' + self.scriptlet
@@ -558,7 +562,7 @@ class Job:
 
 
 
-def which(exe):
+def which(exe:str) -> Optional[str]:
     '''TODO: we could use the PATH= variable from the crontab'''
     for path in os.environ.get('PATH', '/usr/bin:/bin').split(os.pathsep):
         try:
